==> zio-aws-managedblockchainquery_2.13-7.21.15.13-sources.jar: zio/aws/managedblockchainquery/model/package.scala <==
package zio.aws.managedblockchainquery
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.managedblockchainquery.model.primitives.QueryTransactionHash.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object BlockHash extends Subtype[String]
    type BlockHash =
      zio.aws.managedblockchainquery.model.primitives.BlockHash.Type
    object ChainAddress extends Subtype[String]
    type ChainAddress =
      zio.aws.managedblockchainquery.model.primitives.ChainAddress.Type
    type Integer = Int
    object ListAssetContractsInputMaxResultsInteger extends Subtype[Int]
    type ListAssetContractsInputMaxResultsInteger =
      zio.aws.managedblockchainquery.model.primitives.ListAssetContractsInputMaxResultsInteger.Type
    object ListTokenBalancesInputMaxResultsInteger extends Subtype[Int]
    type ListTokenBalancesInputMaxResultsInteger =
      zio.aws.managedblockchainquery.model.primitives.ListTokenBalancesInputMaxResultsInteger.Type
    object ListTransactionEventsInputMaxResultsInteger extends Subtype[Int]
    type ListTransactionEventsInputMaxResultsInteger =
      zio.aws.managedblockchainquery.model.primitives.ListTransactionEventsInputMaxResultsInteger.Type
    object ListTransactionsInputMaxResultsInteger extends Subtype[Int]
    type ListTransactionsInputMaxResultsInteger =
      zio.aws.managedblockchainquery.model.primitives.ListTransactionsInputMaxResultsInteger.Type
    object NextToken extends Subtype[String]
    type NextToken =
      zio.aws.managedblockchainquery.model.primitives.NextToken.Type
    object QueryTokenId extends Subtype[String]
    type QueryTokenId =
      zio.aws.managedblockchainquery.model.primitives.QueryTokenId.Type
    object QueryTransactionHash extends Subtype[String]
    type QueryTransactionHash =
      zio.aws.managedblockchainquery.model.primitives.QueryTransactionHash.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp =
      zio.aws.managedblockchainquery.model.primitives.Timestamp.Type
  }
  type AssetContractList =
    List[zio.aws.managedblockchainquery.model.AssetContract]
  type BatchGetTokenBalanceErrors =
    List[zio.aws.managedblockchainquery.model.BatchGetTokenBalanceErrorItem]
  type BatchGetTokenBalanceOutputList =
    List[zio.aws.managedblockchainquery.model.BatchGetTokenBalanceOutputItem]
  type GetTokenBalanceInputList =
    List[zio.aws.managedblockchainquery.model.BatchGetTokenBalanceInputItem]
  type TokenBalanceList =
    List[zio.aws.managedblockchainquery.model.TokenBalance]
  type TransactionEventList =
    List[zio.aws.managedblockchainquery.model.TransactionEvent]
  type TransactionOutputList =
    List[zio.aws.managedblockchainquery.model.TransactionOutputItem]
}

==> zio-aws-managedblockchainquery_3-7.21.15.3-sources.jar: zio/aws/managedblockchainquery/model/package.scala <==
package zio.aws.managedblockchainquery
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.managedblockchainquery.model.primitives.QueryTransactionHash.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object BlockHash extends Subtype[String]
    type BlockHash =
      zio.aws.managedblockchainquery.model.primitives.BlockHash.Type
    object ChainAddress extends Subtype[String]
    type ChainAddress =
      zio.aws.managedblockchainquery.model.primitives.ChainAddress.Type
    type Integer = Int
    object ListAssetContractsInputMaxResultsInteger extends Subtype[Int]
    type ListAssetContractsInputMaxResultsInteger =
      zio.aws.managedblockchainquery.model.primitives.ListAssetContractsInputMaxResultsInteger.Type
    object ListTokenBalancesInputMaxResultsInteger extends Subtype[Int]
    type ListTokenBalancesInputMaxResultsInteger =
      zio.aws.managedblockchainquery.model.primitives.ListTokenBalancesInputMaxResultsInteger.Type
    object ListTransactionEventsInputMaxResultsInteger extends Subtype[Int]
    type ListTransactionEventsInputMaxResultsInteger =
      zio.aws.managedblockchainquery.model.primitives.ListTransactionEventsInputMaxResultsInteger.Type
    object ListTransactionsInputMaxResultsInteger extends Subtype[Int]
    type ListTransactionsInputMaxResultsInteger =
      zio.aws.managedblockchainquery.model.primitives.ListTransactionsInputMaxResultsInteger.Type
    object NextToken extends Subtype[String]
    type NextToken =
      zio.aws.managedblockchainquery.model.primitives.NextToken.Type
    object QueryTokenId extends Subtype[String]
    type QueryTokenId =
      zio.aws.managedblockchainquery.model.primitives.QueryTokenId.Type
    object QueryTransactionHash extends Subtype[String]
    type QueryTransactionHash =
      zio.aws.managedblockchainquery.model.primitives.QueryTransactionHash.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp =
      zio.aws.managedblockchainquery.model.primitives.Timestamp.Type
  }
  type AssetContractList =
    List[zio.aws.managedblockchainquery.model.AssetContract]
  type BatchGetTokenBalanceErrors =
    List[zio.aws.managedblockchainquery.model.BatchGetTokenBalanceErrorItem]
  type BatchGetTokenBalanceOutputList =
    List[zio.aws.managedblockchainquery.model.BatchGetTokenBalanceOutputItem]
  type GetTokenBalanceInputList =
    List[zio.aws.managedblockchainquery.model.BatchGetTokenBalanceInputItem]
  type TokenBalanceList =
    List[zio.aws.managedblockchainquery.model.TokenBalance]
  type TransactionEventList =
    List[zio.aws.managedblockchainquery.model.TransactionEvent]
  type TransactionOutputList =
    List[zio.aws.managedblockchainquery.model.TransactionOutputItem]
}
